package jp.gr.java_conf.akabeko.testgradientquality;

import android.app.Activity;
import android.content.Intent;
import android.graphics.PixelFormat;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.RadioGroup;
import android.widget.RadioGroup.OnCheckedChangeListener;

/**
 * トップ画面を表します。
 */
public class TopActivity extends Activity implements OnClickListener, OnCheckedChangeListener {
	/**
	 * グラデーション色。
	 */
	private int mGradientColor = R.drawable.shape_gradient_red;

	/**
	 * ピクセル品質。
	 */
	private int mPixelFormat = PixelFormat.RGB_565;

	/**
	 * View がクリックされた時に発生します。
	 *
	 * @param view クリックされた View。
	 */
	public void onClick( View view ) {
		Intent intent = new Intent();
		intent.setClass( this, GradientActivity.class );
		intent.putExtra( GradientActivity.EXTRA_GRADIENT,     this.mGradientColor );
		intent.putExtra( GradientActivity.EXTRA_PIXEL_FORMAT, this.mPixelFormat   );

		this.startActivity( intent );
	}

	/**
	 * ラジオグループ内でチェック操作が行われた時に発生します。
	 *
	 * @param group     グループ。
	 * @param checkedId チェックされたラジオボタンの識別子。
	 */
	public void onCheckedChanged( RadioGroup group, int checkedId ) {
		switch( group.getId() ) {
		// グラデーション
		case R.id.radio_group_gradient_color:
			switch( checkedId ) {
			case R.id.radio_red:
				this.mGradientColor = R.drawable.shape_gradient_red;
				break;

			case R.id.radio_green:
				this.mGradientColor = R.drawable.shape_gradient_green;
				break;

			case R.id.radio_blue:
				this.mGradientColor = R.drawable.shape_gradient_blue;
				break;
			}
			break;

		// ピクセル品質
		case R.id.radio_group_pixel_format:
			switch( checkedId ) {
			case R.id.radio_rgb_565:
				this.mPixelFormat = PixelFormat.RGB_565;
				break;

			case R.id.radio_rgba_8888:
				this.mPixelFormat = PixelFormat.RGBA_8888;
				break;

			case R.id.radio_rgba_4444:
				this.mPixelFormat = PixelFormat.RGBA_4444;
				break;

			}
			break;
		}
	}

	/**
	 * 画面が作成される時に発生します。
	 *
	 * @param savedInstanceState 保存されたインスタンスの状態。
	 */
	@Override
	public void onCreate( Bundle savedInstanceState ) {
		super.onCreate( savedInstanceState );
		this.getWindow().setFormat( PixelFormat.RGBA_8888 );
		this.setContentView( R.layout.top );

		this.findViewById( R.id.show ).setOnClickListener( this );
		( ( RadioGroup )this.findViewById( R.id.radio_group_gradient_color ) ).setOnCheckedChangeListener( this );
		( ( RadioGroup )this.findViewById( R.id.radio_group_pixel_format   ) ).setOnCheckedChangeListener( this );
	}
}